==> nextcloud-18.0.4.tgz: nextcloud/apps/accessibility/l10n/pl.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Ciemny motyw",
    "Enable dark theme" : "Włącz ciemny motyw",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ciemny motyw, który łagodzi zmęczenie oczu, zmniejszając ogólną jasność. Nadal jest w fazie rozwoju, więc proszę zgłaszać wszelkie zauważone błędy.",
    "High contrast mode" : "Tryb dużego kontrastu",
    "Enable high contrast mode" : "Włącz tryb dużego kontrastu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tryb dużego kontrastu ułatwiający nawigację. Jakość obrazu zostanie zmniejszona, celem poprawy przejrzystości.",
    "Dyslexia font" : "Czcionka dla dyslektyków",
    "Enable dyslexia font" : "Włącz czcionkę dla dyslektyków",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic to darmowa czcionka zaprojektowana w celu zmniejszenia niektórych typowych błędów w czytaniu spowodowanych dysleksją.",
    "Accessibility" : "Dostępność",
    "Accessibility options for nextcloud" : "Opcje dostępności dla Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Zapewnia wiele opcji dostępu, aby ułatwić korzystanie z Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalny dostęp jest dla nas bardzo ważny. Przestrzegamy standardów internetowych i sprawdzamy, aby wszystko było użyteczne również bez myszy i oprogramowania pomocniczego, takiego jak czytniki ekranu. Naszym celem jest zgodność z {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na poziomie AA, z motywem o wysokim kontraście nawet na poziomie AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Jeśli znajdziesz jakieś problemy, nie wahaj się zgłosić je na {issuetracker}listę błędów{linkend}. A jeśli chcesz się zaangażować, dołącz do {designteam}!",
    "High contrast theme" : "Motyw o dużym kontraście",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Motyw o dużym kontraście ułatwiający nawigację. Jakość obrazu jest zmniejszona, ale za to poprawiona przejrzystość.",
    "Dark theme (beta)" : "Ciemny motyw (beta)",
    "Web Content Accessibility Guidelines" : "Web Content Accessibility Guidelines",
    "our issue tracker" : "na listę błędów ",
    "our design team" : "naszego zespołu projektowego",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalny dostęp jest dla nas bardzo ważny. Przestrzegamy standardów internetowych i sprawdzamy, aby wszystko było użyteczne również bez myszy i oprogramowania pomocniczego, takiego jak czytniki ekranu. Naszym celem jest zgodność z {guidelines} 2.1 na poziomie AA, z motywem o wysokim kontraście nawet na poziomie AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "Jeśli znajdziesz jakieś problemy, nie wahaj się zgłosić je na {issuetracker}. A jeśli chcesz się zaangażować, dołącz do {designteam}!",
    "Enable" : "Włącz"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-18.0.7.tgz: nextcloud/apps/accessibility/l10n/pl.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Ciemny motyw",
    "Enable dark theme" : "Włącz ciemny motyw",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ciemny motyw, który łagodzi zmęczenie oczu, zmniejszając ogólną jasność. Nadal jest w fazie rozwoju, więc proszę zgłaszać wszelkie zauważone błędy.",
    "High contrast mode" : "Tryb wysokiego kontrastu",
    "Enable high contrast mode" : "Włącz tryb wysokiego kontrastu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Tryb wysokiego kontrastu ułatwiający nawigację. Jakość obrazu zostanie zmniejszona, celem poprawy przejrzystości.",
    "Dyslexia font" : "Czcionka dla dyslektyków",
    "Enable dyslexia font" : "Włącz czcionkę dla dyslektyków",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic to darmowa czcionka zaprojektowana w celu zmniejszenia niektórych typowych błędów w czytaniu spowodowanych dysleksją.",
    "Accessibility" : "Dostępność",
    "Accessibility options for nextcloud" : "Opcje dostępności dla Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Zapewnia wiele opcji dostępu, aby ułatwić korzystanie z Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalny dostęp jest dla nas bardzo ważny. Przestrzegamy standardów internetowych i sprawdzamy, aby wszystko było użyteczne również bez myszy i oprogramowania pomocniczego, takiego jak czytniki ekranu. Naszym celem jest zgodność z {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na poziomie AA, z motywem o wysokim kontraście nawet na poziomie AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Jeśli znajdziesz jakieś problemy, nie wahaj się zgłosić je na {issuetracker}listę błędów{linkend}. A jeśli chcesz się zaangażować, dołącz do {designteam}naszego zespołu projektowego{linkend}!",
    "High contrast theme" : "Motyw o dużym kontraście",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Motyw o dużym kontraście ułatwiający nawigację. Jakość obrazu jest zmniejszona, ale za to poprawiona przejrzystość.",
    "Web Content Accessibility Guidelines" : "Web Content Accessibility Guidelines",
    "our issue tracker" : "na listę błędów ",
    "our design team" : "naszego zespołu projektowego",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalny dostęp jest dla nas bardzo ważny. Przestrzegamy standardów internetowych i sprawdzamy, aby wszystko było użyteczne również bez myszy i oprogramowania pomocniczego, takiego jak czytniki ekranu. Naszym celem jest zgodność z {guidelines} 2.1 na poziomie AA, z motywem o wysokim kontraście nawet na poziomie AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "Jeśli znajdziesz jakieś problemy, nie wahaj się zgłosić je na {issuetracker}. A jeśli chcesz się zaangażować, dołącz do {designteam}!",
    "Enable" : "Włącz"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
